Array

Struct Array 

pub struct Array<S = SmolStr>(pub Vec<Data<S>>)
where
    S: Bos<str> + AsRef<str>;
Array of AT Protocol data values

Tuple Fields

0: Vec<Data<S>>

Implementations

Source

impl<S> Array<S>
where S: Bos<str> + AsRef<str>,

pub fn convert<B>(self) -> Array<B>
where B: Bos<str> + AsRef<str> + From<S>,

Convert to an Array with a different backing type.

Source

impl<S> Array<S>
where S: Bos<str> + AsRef<str>,

pub fn len(&self) -> usize

Get the number of elements in the array

pub fn is_empty(&self) -> bool

Check if the array is empty

pub fn get(&self, index: usize) -> Option<&Data<S>>

Get an element by index

pub fn get_mut(&mut self, index: usize) -> Option<&mut Data<S>>

Get a mutable reference to an element by index

pub fn iter(&self) -> Iter<'_, Data<S>>

Get an iterator over the array elements