DefaultStr

Type Alias DefaultStr 

pub type DefaultStr = SmolStr;
The default string backing type for jacquard’s type-parameterised types.

SmolStr is used as the default because it satisfies DeserializeOwned (no lifetime annotation required) and provides small-string inline storage without heap allocation for strings of 22 bytes or fewer.

Aliased Type

pub struct DefaultStr(/* private fields */);